Module agent

Module agent 

Agent module for the Oxyde SDK

This module provides the core Agent type, which represents an AI-driven NPC in a game environment. Agents have behaviors, memory, and can interact with players.

Re-exports

pub use crate::AgentContext;

Structs

Agent
Agent represents an AI-powered NPC in a game
AgentBuilder
AgentBuilder for fluent construction of Agents
CallbackWrapper
Wrapper for agent callbacks to make them Debug-able

Enums

AgentEvent
Agent event types for callbacks
AgentState
Agent state

Type Aliases

AgentCallback
Callback for agent events