Agent module for the Oxyde SDK
This module provides the core Agent type, which represents an AI-driven NPC in a game environment. Agents have behaviors, memory, and can interact with players.
Re-exports
pub use crate::AgentContext;
Structs
- Agent
- Agent represents an AI-powered NPC in a game
- Agent
Builder - AgentBuilder for fluent construction of Agents
- Callback
Wrapper - Wrapper for agent callbacks to make them Debug-able
Enums
- Agent
Event - Agent event types for callbacks
- Agent
State - Agent state
Type Aliases
- Agent
Callback - Callback for agent events